<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class XforWC_AddTabs_Settings {

	public static $plugin;

	public static function init() {

		self::$plugin = array(
			'name'    => 'Add Product Tabs for WooCommerce',
			'xforwc'  => 'Product Tabs',
			'slug'    => 'add-tabs-xforwc',
			'label'   => 'add_tabs_xforwc',
			'image'   => XforWC_AddTabs()->plugin_url() . '/includes/images/add-product-tabs-for-woocommerce.png',
			'path'    => 'add-tabs-xforwc/add-tabs-xforwc',
			'version' => XforWC_AddTabs::$version,
		);

		if ( isset( $_GET['page'], $_GET['tab'] ) && 'wc-settings' === $_GET['page'] && 'add_tabs_xforwc' === $_GET['tab'] ) {
			add_filter( 'svx_plugins_settings', array( 'XforWC_AddTabs_Settings', 'get_settings' ), 50 );
		}

		if ( function_exists( 'XforWC' ) ) {
			add_filter( 'xforwc_settings', array( 'XforWC_AddTabs_Settings', 'xforwc' ), 9999999171 );
			add_filter( 'xforwc_svx_get_add_tabs_xforwc', array( 'XforWC_AddTabs_Settings', '_get_settings_xforwc' ) );
		}

		add_filter( 'svx_plugins', array( 'XforWC_AddTabs_Settings', 'add_plugin' ), 0 );
	}

	public static function xforwc( $settings ) {
		$settings['plugins'][] = self::$plugin;

		return $settings;
	}

	public static function add_plugin( $plugins ) {
		$plugins[ self::$plugin['label'] ] = array(
			'slug' => self::$plugin['label'],
			'name' => self::$plugin['xforwc'],
		);

		return $plugins;
	}

	public static function _get_settings_xforwc() {
		$settings = self::get_settings( array() );
		return $settings[ self::$plugin['label'] ];
	}

	public static function get_settings( $plugins ) {

		$plugins[ self::$plugin['label'] ] = array(
			'slug'     => self::$plugin['label'],
			'name'     => esc_html( function_exists( 'XforWC' ) ? self::$plugin['xforwc'] : self::$plugin['name'] ),
			'desc'     => esc_html( function_exists( 'XforWC' ) ? self::$plugin['name'] . ' v' . self::$plugin['version'] : esc_html__( 'Settings page for', '^xwc' ) . ' ' . self::$plugin['name'] ),
			'link'     => esc_url( 'https://xforwoocommerce.com/store/product-tabs/' ),
			'ref'      => array(
				'name' => esc_html__( 'Visit XforWooCommerce.com', '^xwc' ),
				'url'  => 'https://xforwoocommerce.com',
			),
			'doc'      => array(
				'name' => esc_html__( 'Get help', '^xwc' ),
				'url'  => 'https://help.xforwoocommerce.com',
			),
			'sections' => array(
				'dashboard' => array(
					'name' => esc_html__( 'Dashboard', '^xwc' ),
					'desc' => esc_html__( 'Dashboard Overview', '^xwc' ),
				),
				'tabs'      => array(
					'name' => esc_html__( 'Tabs Manager', '^xwc' ),
					'desc' => esc_html__( 'Tabs Manager Options', '^xwc' ),
				),
				'general'   => array(
					'name' => esc_html__( 'General', '^xwc' ),
					'desc' => esc_html__( 'General Options', '^xwc' ),
				),
			),
			'settings' => array(

				'wcmn_dashboard'             => array(
					'type'    => 'html',
					'id'      => 'wcmn_dashboard',
					'desc'    => '	
                            <h3><span class="dashicons dashicons-store"></span> XforWooCommerce</h3>
                            <p>' . esc_html__( 'Visit XforWooCommerce.com store, demos and knowledge base.', '^xwc' ) . '</p>
                            <p><a href="https://xforwoocommerce.com" class="xforwc-button-primary x-color" target="_blank">XforWooCommerce.com</a></p>

                            <br /><hr />

                            <h3><span class="dashicons dashicons-admin-tools"></span> ' . esc_html__( 'Help Center', '^xwc' ) . '</h3>
                            <p>' . esc_html__( 'Need support? Visit the Help Center.', '^xwc' ) . '</p>
                            <p><a href="https://help.xforwoocommerce.com" class="xforwc-button-primary red" target="_blank">XforWooCommerce.com HELP</a></p>
                            
                            <br /><hr />

                            <h3><span class="dashicons dashicons-update"></span> ' . esc_html__( 'Automatic Updates', '^xwc' ) . '</h3>
                            <p>' . esc_html__( 'Get automatic updates, by downloading and installing the Envato Market plugin.', '^xwc' ) . '</p>
                            <p><a href="https://envato.com/market-plugin/" class="svx-button" target="_blank">Envato Market Plugin</a></p>
                            
                            <br />',
					'section' => 'dashboard',
				),

				'wcmn_utility'               => array(
					'name'    => esc_html__( 'Plugin Options', '^xwc' ),
					'type'    => 'utility',
					'id'      => 'wcmn_utility',
					'desc'    => esc_html__( 'Quick export/import, backup and restore, or just reset your optons here', '^xwc' ),
					'section' => 'dashboard',
				),

				'tabs'                       => array(
					'name'      => esc_html__( 'Tabs Manager', '^xwc' ),
					'type'      => 'list-select',
					'desc'      => esc_html__( 'Use the tabs manager to add tabs!', '^xwc' ),
					'id'        => 'tabs',
					'default'   => array(),
					'autoload'  => false,
					'section'   => 'tabs',
					'options'   => 'list',
					'translate' => true,
					'selects'   => array(
						'csv'          => esc_html__( 'Table from CSV', '^xwc' ),
						'image'        => esc_html__( 'Image', '^xwc' ),
						'video'        => esc_html__( 'Video', '^xwc' ),
						'html'         => esc_html__( 'Text, HTML, Shortcode', '^xwc' ),
						'product_meta' => esc_html__( 'Product Meta', '^xwc' ),
					),
					'settings'  => array(
						'csv'          => array(
							'name'      => array(
								'name'    => esc_html__( 'Name', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab name', '^xwc' ),
								'id'      => 'name',
								'default' => '',
							),
							'csv'       => array(
								'name'    => esc_html__( 'CSV', '^xwc' ),
								'type'    => 'file',
								'desc'    => esc_html__( 'Enter .csv file URL', '^xwc' ),
								'id'      => 'csv',
								'default' => '',
							),
							'options'   => array(
								'name'     => esc_html__( 'CSV Values', '^xwc' ),
								'type'     => 'list-select',
								'desc'     => esc_html__( 'Use this option to replace CSV values with images or HTML', '^xwc' ),
								'id'       => 'options',
								'default'  => array(),
								'options'  => 'list',
								'selects'  => array(
									'image' => esc_html__( 'Image', '^xwc' ),
									'html'  => esc_html__( 'Text, HTML, Shortcode', '^xwc' ),
								),
								'settings' => array(
									'image' => array(
										'name'  => array(
											'name'    => esc_html__( 'Name', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value name', '^xwc' ),
											'id'      => 'name',
											'default' => '',
										),
										'value' => array(
											'name'    => esc_html__( 'Value', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value to replace', '^xwc' ),
											'id'      => 'value',
											'default' => '',
										),
										'image' => array(
											'name'    => esc_html__( 'Image', '^xwc' ),
											'type'    => 'file',
											'desc'    => esc_html__( 'Enter CSV value replacement image URL', '^xwc' ),
											'id'      => 'image',
											'default' => '',
										),
									),
									'html'  => array(
										'name'  => array(
											'name'    => esc_html__( 'Name', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value name', '^xwc' ),
											'id'      => 'name',
											'default' => '',
										),
										'value' => array(
											'name'    => esc_html__( 'Value', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value to replace', '^xwc' ),
											'id'      => 'value',
											'default' => '',
										),
										'html'  => array(
											'name'    => esc_html__( 'Text, HTML, Shortcode', '^xwc' ),
											'type'    => 'textarea',
											'desc'    => esc_html__( 'Enter CSV value replacement text, HTML or shortcode', '^xwc' ),
											'id'      => 'html',
											'default' => '',
										),
									),
								),
							),
							'condition' => array(
								'name'    => esc_html__( 'Display Condition', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab display condition E.G. !is_singular:my-product-slug', '^xwc' ),
								'id'      => 'condition',
								'default' => '',
							),
						),
						'image'        => array(
							'name'      => array(
								'name'    => esc_html__( 'Name', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab name', '^xwc' ),
								'id'      => 'name',
								'default' => '',
							),
							'image'     => array(
								'name'    => esc_html__( 'Image', '^xwc' ),
								'type'    => 'file',
								'desc'    => esc_html__( 'Enter image URL', '^xwc' ),
								'id'      => 'image',
								'default' => '',
							),
							'condition' => array(
								'name'    => esc_html__( 'Display Condition', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab display condition E.G. !is_singular:my-product-slug', '^xwc' ),
								'id'      => 'condition',
								'default' => '',
							),
						),
						'video'        => array(
							'name'      => array(
								'name'    => esc_html__( 'Name', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab name', '^xwc' ),
								'id'      => 'name',
								'default' => '',
							),
							'video'     => array(
								'name'    => esc_html__( 'Video URL', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter YouTube video URL E.G. https://www.youtube.com/watch?v=Wt2zOAZsbJo', '^xwc' ),
								'id'      => 'video',
								'default' => '',
							),
							'condition' => array(
								'name'    => esc_html__( 'Display Condition', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab display condition E.G. !is_singular:my-product-slug', '^xwc' ),
								'id'      => 'condition',
								'default' => '',
							),
						),
						'html'         => array(
							'name'      => array(
								'name'    => esc_html__( 'Name', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab name', '^xwc' ),
								'id'      => 'name',
								'default' => '',
							),
							'html'      => array(
								'name'    => esc_html__( 'Text, HTML, Shortcode', '^xwc' ),
								'type'    => 'textarea',
								'desc'    => esc_html__( 'Enter text, HTML or shortcode', '^xwc' ),
								'id'      => 'html',
								'default' => '',
							),
							'condition' => array(
								'name'    => esc_html__( 'Display Condition', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab display condition E.G. !is_singular:my-product-slug', '^xwc' ),
								'id'      => 'condition',
								'default' => '',
							),
						),
						'product_meta' => array(
							'name'      => array(
								'name'    => esc_html__( 'Name', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab name', '^xwc' ),
								'id'      => 'name',
								'default' => '',
							),
							'key'       => array(
								'name'    => esc_html__( 'Meta key', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter Meta Key', '^xwc' ),
								'id'      => 'key',
								'default' => '',
							),
							'meta_type' => array(
								'name'    => esc_html__( 'Meta type', '^xwc' ),
								'type'    => 'select',
								'desc'    => esc_html__( 'Select meta type', '^xwc' ),
								'id'      => 'meta_type',
								'options' => array(
									'csv'   => esc_html__( 'Table from CSV', '^xwc' ),
									'image' => esc_html__( 'Image', '^xwc' ),
									'video' => esc_html__( 'Video', '^xwc' ),
									'html'  => esc_html__( 'Text, HTML, Shortcode', '^xwc' ),
								),
								'default' => 'html',
							),
							'add_field' => array(
								'name'    => esc_html__( 'Add Product Field', '^xwc' ),
								'type'    => 'checkbox',
								'desc'    => esc_html__( 'Add meta key field to edit product screen', '^xwc' ),
								'id'      => 'add_field',
								'default' => 'yes',
							),
							'options'   => array(
								'name'     => esc_html__( 'CSV Values', '^xwc' ),
								'type'     => 'list-select',
								'desc'     => esc_html__( 'Use this option to replace CSV values with images or HTML', '^xwc' ),
								'id'       => 'options',
								'default'  => array(),
								'options'  => 'list',
								'selects'  => array(
									'image' => esc_html__( 'Image', '^xwc' ),
									'html'  => esc_html__( 'Text, HTML, Shortcode', '^xwc' ),
								),
								'settings' => array(
									'image' => array(
										'name'  => array(
											'name'    => esc_html__( 'Name', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value name', '^xwc' ),
											'id'      => 'name',
											'default' => '',
										),
										'value' => array(
											'name'    => esc_html__( 'Value', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value to replace', '^xwc' ),
											'id'      => 'value',
											'default' => '',
										),
										'image' => array(
											'name'    => esc_html__( 'Image', '^xwc' ),
											'type'    => 'file',
											'desc'    => esc_html__( 'Enter CSV value replacement image URL', '^xwc' ),
											'id'      => 'image',
											'default' => '',
										),
									),
									'html'  => array(
										'name'  => array(
											'name'    => esc_html__( 'Name', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value name', '^xwc' ),
											'id'      => 'name',
											'default' => '',
										),
										'value' => array(
											'name'    => esc_html__( 'Value', '^xwc' ),
											'type'    => 'text',
											'desc'    => esc_html__( 'Enter CSV value to replace', '^xwc' ),
											'id'      => 'value',
											'default' => '',
										),
										'html'  => array(
											'name'    => esc_html__( 'Text, HTML, Shortcode', '^xwc' ),
											'type'    => 'textarea',
											'desc'    => esc_html__( 'Enter CSV value replacement text, HTML or shortcode', '^xwc' ),
											'id'      => 'html',
											'default' => '',
										),
									),
								),
							),
							'condition' => array(
								'name'    => esc_html__( 'Display Condition', '^xwc' ),
								'type'    => 'text',
								'desc'    => esc_html__( 'Enter tab display condition E.G. !is_singular:my-product-slug', '^xwc' ),
								'id'      => 'condition',
								'default' => '',
							),
						),
					),
				),

				'description'                => array(
					'name'      => esc_html__( 'Rename Description', '^xwc' ),
					'type'      => 'text',
					'desc'      => esc_html__( 'Rename short description tab', '^xwc' ),
					'id'        => 'description',
					'default'   => '',
					'translate' => true,
					'autoload'  => false,
					'section'   => 'general',
				),

				'description_off'            => array(
					'name'     => esc_html__( 'Hide Description', '^xwc' ),
					'type'     => 'checkbox',
					'desc'     => esc_html__( 'Hide short description tab', '^xwc' ),
					'id'       => 'description_off',
					'default'  => '',
					'autoload' => false,
					'section'  => 'general',
				),

				'additional_information'     => array(
					'name'      => esc_html__( 'Rename Additional Information', '^xwc' ),
					'type'      => 'text',
					'desc'      => esc_html__( 'Rename additional information tab', '^xwc' ),
					'id'        => 'additional_information',
					'default'   => '',
					'translate' => true,
					'autoload'  => false,
					'section'   => 'general',
				),

				'additional_information_off' => array(
					'name'     => esc_html__( 'Hide Additional Information', '^xwc' ),
					'type'     => 'checkbox',
					'desc'     => esc_html__( 'Hide additional information tab', '^xwc' ),
					'id'       => 'additional_information_off',
					'default'  => '',
					'autoload' => false,
					'section'  => 'general',
				),

			),
		);

		return SevenVX()->_do_options( $plugins, self::$plugin['label'] );

	}

}

	XforWC_AddTabs_Settings::init();
