<?php
/*
Plugin Name: Floating Cart
Plugin URI: https://xforwoocommerce.com
Description: XforWooCommerce Themes and Plugins! Visit https://xforwoocommerce.com
Author: XforWooCommerce
License: Codecanyon Split Licence
Version: 2.0.2
Requires at least: 4.5
Tested up to: 7.9.9
WC requires at least: 3.5.0
WC tested up to: 8.9.9
Author URI: https://xforwoocommerce.com
Text Domain: floating-cart-xforwc
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'XforWC' ) ) {
	require_once 'includes/svx-settings/load.php';

	if ( xforwccb() ) {
		return false; }
}

$GLOBALS['svx'] = isset( $GLOBALS['svx'] ) && 1 === version_compare( $GLOBALS['svx'], '1.7.2' ) ? $GLOBALS['svx'] : '1.7.2';

if ( ! class_exists( 'XforWC_FloatingCart' ) ) :

	final class XforWC_FloatingCart {

		public static $version = '2.0.2';

		protected static $_instance = null;

		public static function instance() {

			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function __construct() {
			do_action( 'floating_cart_xforwc_loading' );

			$this->includes();

			if ( ! function_exists( 'XforWC' ) ) {
				$this->single_plugin();
			}

			do_action( 'floating_cart_xforwc_loaded' );
		}

		private function single_plugin() {
			if ( is_admin() ) {
				register_activation_hook( __FILE__, array( $this, 'activate' ) );
			}

			include_once 'includes/svx-settings/svx-get.php';
			add_action( 'init', array( $this, 'load_svx' ), 100 );

			// Texdomain only used if out of XforWC
			add_action( 'init', array( $this, 'textdomain' ), 0 );

			add_action(
				'before_woocommerce_init',
				function() {
					if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
						\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
					}
				}
			);
		}

		public function activate() {
			if ( ! class_exists( 'WooCommerce' ) ) {
				deactivate_plugins( plugin_basename( __FILE__ ) );

				wp_die( esc_html__( 'This plugin requires WooCommerce. Download it from WooCommerce official website', '^xwc' ) . ' &rarr; https://woo.com' );
				exit;
			}
		}

		public function load_svx() {
			if ( is_admin() ) {
				include_once 'includes/svx-settings/svx-settings.php';

				SevenVX()->init_plugin( 'floating_cart_xforwc' );
			}
		}

		private function is_request( $type ) {
			switch ( $type ) {
				case 'admin':
					return is_admin();
				case 'ajax':
					return defined( 'DOING_AJAX' );
				case 'cron':
					return defined( 'DOING_CRON' );
				case 'frontend':
					return ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' );
			}
		}

		public function includes() {
			if ( is_admin() ) {
				include_once 'includes/class-settings.php';
			}

			include_once 'includes/class-front.php';
		}

		public function textdomain() {
			$this->load_plugin_textdomain();
		}

		public function load_plugin_textdomain() {

			$domain = 'floating-cart-xforwc';
			$dir    = untrailingslashit( WP_LANG_DIR );
			$locale = apply_filters( 'plugin_locale', get_locale(), $domain );
			$loaded = load_textdomain( $domain, $dir . '/plugins/' . $domain . '-' . $locale . '.mo' );

			if ( $loaded ) {
				return $loaded;
			} else {
				load_plugin_textdomain( $domain, false, basename( dirname( __FILE__ ) ) . '/lang/' );
			}

		}

		public function plugin_url() {
			return untrailingslashit( plugins_url( '/', __FILE__ ) );
		}

		public function plugin_path() {
			return untrailingslashit( plugin_dir_path( __FILE__ ) );
		}

		public function plugin_basename() {
			return untrailingslashit( plugin_basename( __FILE__ ) );
		}

		public function ajax_url() {
			return admin_url( 'admin-ajax.php', 'relative' );
		}

		public function version() {
			return self::$version;
		}

	}

	function XforWC_FloatingCart() {
		return XforWC_FloatingCart::instance();
	}

	XforWC_FloatingCart::instance();

endif;
