<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class XforWC_SEO_Settings {

	public static $plugin;

	public static function init() {

		self::$plugin = array(
			'name'    => 'Autopilot SEO for WooCommerce',
			'xforwc'  => 'Seach Engine Optimization (SEO)',
			'slug'    => 'seo-for-woocommerce',
			'label'   => 'seo_for_woocommerce',
			'image'   => XforWC_SEO()->plugin_url() . '/includes/images/autopilot-seo-for-woocommerce-elements.png',
			'path'    => 'seo-for-woocommerce/seo-for-woocommerce',
			'version' => XforWC_SEO::$version,
		);

		if ( isset( $_GET['page'], $_GET['tab'] ) && 'wc-settings' === $_GET['page'] && 'seo_for_woocommerce' === $_GET['tab'] ) {
			add_filter( 'svx_plugins_settings', array( 'XforWC_SEO_Settings', 'get_settings' ), 50 );
		}

		if ( function_exists( 'XforWC' ) ) {
			add_filter( 'xforwc_settings', array( 'XforWC_SEO_Settings', 'xforwc' ), 9999999131 );
			add_filter( 'xforwc_svx_get_seo_for_woocommerce', array( 'XforWC_SEO_Settings', '_get_settings_xforwc' ) );
		}

		add_action( 'admin_enqueue_scripts', array( 'XforWC_SEO_Settings', 'scripts' ) );

		add_filter( 'svx_plugins', array( 'XforWC_SEO_Settings', 'add_plugin' ), 0 );

	}

	public static function xforwc( $settings ) {
		$settings['plugins'][] = self::$plugin;

		return $settings;
	}

	public static function add_plugin( $plugins ) {
		$plugins[ self::$plugin['label'] ] = array(
			'slug' => self::$plugin['label'],
			'name' => self::$plugin['xforwc'],
		);

		return $plugins;
	}

	public static function _get_settings_xforwc() {
		$settings = self::get_settings( array() );
		return $settings[ self::$plugin['label'] ];
	}

	public static function scripts( $hook ) {

		if ( 'woocommerce_page_wc-settings' === $hook && isset( $_GET['page'], $_GET['tab'] ) && 'wc-settings' === $_GET['page'] && 'seo_for_woocommerce' === $_GET['tab'] ) {
			$init = true;
		}

		if ( isset( $_GET['page'] ) && 'xforwoocommerce' === $_GET['page'] ) {
			$init = true;
		}

		if ( in_array( $hook, array( 'post.php', 'post-new.php', 'woocommerce_page_wc-settings' ), true ) ) {
			$init = true;
		}

		if ( ! isset( $init ) ) {
			return false;
		}

		$autopilot['hook']      = $hook;
		$autopilot['site_name'] = get_bloginfo( 'name' );
		$autopilot['home_url']  = home_url( '/' );
		$autopilot['tools']     = array(
			array(
				'%site-title%',
				'common',
				esc_html__( 'Site title', '^xwc' ),
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'%site-tagline%',
				'common',
				esc_html__( 'Site tagline', '^xwc' ),
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'%title%',
				'common',
				esc_html__( 'Title', '^xwc' ),
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'%content%',
				'common',
				esc_html__( 'Content', '^xwc' ),
				array( 'page', 'post', 'shop' ),
			),
			array(
				'%excerpt%',
				'common',
				esc_html__( 'Excerpt', '^xwc' ),
				array( 'page', 'post', 'shop' ),
			),
			array(
				'%separator%',
				'special',
				esc_html__( 'Separator', '^xwc' ),
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'%archive-title%',
				'archive',
				esc_html__( 'Archive title', '^xwc' ),
				array( 'blog', 'product_taxonomy' ),
			),
			array(
				'%archive-desc%',
				'archive',
				esc_html__( 'Archive description', '^xwc' ),
				array( 'blog', 'product_taxonomy' ),
			),
			array(
				'%archive-name%',
				'archive',
				esc_html__( 'Archive name', '^xwc' ),
				array( 'blog', 'product_taxonomy' ),
			),
			array(
				'%currency%',
				'woocommerce',
				esc_html__( 'Currency', '^xwc' ),
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'%product-content%',
				'woocommerce',
				esc_html__( 'Product content', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%product-short-desc%',
				'woocommerce',
				esc_html__( 'Product short description', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%price%',
				'woocommerce',
				esc_html__( 'Price', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%regular-price%',
				'woocommerce',
				esc_html__( 'Regular price', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%sale-price%',
				'woocommerce',
				esc_html__( 'Sale price', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%product-cat%',
				'woocommerce',
				esc_html__( 'Product category', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%product-tag%',
				'woocommerce',
				esc_html__( 'Product tag', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%brand%',
				'woocommerce',
				esc_html__( 'Product brand', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%manufacturer%',
				'woocommerce',
				esc_html__( 'Product manufacturer', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%availability%',
				'woocommerce',
				esc_html__( 'Product availability', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%color%',
				'woocommerce',
				esc_html__( 'Product color', '^xwc' ),
				array( 'product' ),
			),
			array(
				'%condition%',
				'woocommerce',
				esc_html__( 'Product condition', '^xwc' ),
				array( 'product' ),
			),

			array(
				'←',
				'separator',
				'&larr;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'→',
				'separator',
				'&rarr;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'–',
				'separator',
				'&ndash;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'—',
				'separator',
				'&mdash;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'·',
				'separator',
				'&middot;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'⋅',
				'separator',
				'&middot;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'•',
				'separator',
				'&bull;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'♥',
				'separator',
				'&hearts;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'★',
				'separator',
				'&#x2605;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
			array(
				'☆',
				'separator',
				'&#x2606;',
				array( 'page', 'post', 'blog', 'shop', 'product', 'product_taxonomy' ),
			),
		);

		wp_register_script( 'seo-wc-js', XforWC_SEO()->plugin_url() . '/includes/js/admin.js', array( 'jquery' ), XforWC_SEO()->version(), true );
		wp_enqueue_script( 'seo-wc-js' );

		wp_localize_script( 'seo-wc-js', 'autopilot', $autopilot );

		wp_register_style( 'seo-wc-css', XforWC_SEO()->plugin_url() . '/includes/css/admin' . ( is_rtl() ? '-rtl' : '' ) . '.css', XforWC_SEO()->version() );
		wp_enqueue_style( 'seo-wc-css' );
	}

	public static function get_settings( $plugins ) {

		$plugins[ self::$plugin['label'] ] = array(
			'slug'     => self::$plugin['label'],
			'name'     => esc_html( function_exists( 'XforWC' ) ? self::$plugin['xforwc'] : self::$plugin['name'] ),
			'desc'     => esc_html( function_exists( 'XforWC' ) ? self::$plugin['name'] . ' v' . self::$plugin['version'] : esc_html__( 'Settings page for', '^xwc' ) . ' ' . self::$plugin['name'] ),
			'link'     => esc_url( 'https://xforwoocommerce.com/store/search-engine-optimization-seo/' ),
			'ref'      => array(
				'name' => esc_html__( 'Visit XforWooCommerce.com', '^xwc' ),
				'url'  => 'https://xforwoocommerce.com',
			),
			'doc'      => array(
				'name' => esc_html__( 'Get help', '^xwc' ),
				'url'  => 'https://help.xforwoocommerce.com',
			),
			'sections' => array(
				'dashboard'   => array(
					'name' => esc_html__( 'Dashboard', '^xwc' ),
					'desc' => esc_html__( 'Dashboard Overview', '^xwc' ),
				),
				'social'      => array(
					'name' => esc_html__( 'Social', '^xwc' ),
					'desc' => esc_html__( 'Social Options', '^xwc' ),
				),
				'woocommerce' => array(
					'name' => esc_html__( 'WooCommerce', '^xwc' ),
					'desc' => esc_html__( 'WooCommerce Options', '^xwc' ),
				),
				'product'     => array(
					'name' => esc_html__( 'Product Page', '^xwc' ),
					'desc' => esc_html__( 'Product Page Options', '^xwc' ),
				),
				'shop'        => array(
					'name' => esc_html__( 'Shop/Archive', '^xwc' ),
					'desc' => esc_html__( 'Shop/Archive Options', '^xwc' ),
				),
				'pages'       => array(
					'name' => esc_html__( 'Pages', '^xwc' ),
					'desc' => esc_html__( 'Pages Options', '^xwc' ),
				),
				'blog'        => array(
					'name' => esc_html__( 'Blog', '^xwc' ),
					'desc' => esc_html__( 'Blog Options', '^xwc' ),
				),
				'meta'        => array(
					'name' => esc_html__( 'Add Meta', '^xwc' ),
					'desc' => esc_html__( 'Add Meta Options', '^xwc' ),
				),
			),
			'settings' => array(

				'wcmn_dashboard'          => array(
					'type'    => 'html',
					'id'      => 'wcmn_dashboard',
					'desc'    => '<div class="seo-alexa"><p class="check-options"></p></div>

						<h3><span class="dashicons dashicons-store"></span> XforWooCommerce</h3>
						<p>' . esc_html__( 'Visit XforWooCommerce.com store, demos and knowledge base.', '^xwc' ) . '</p>
						<p><a href="https://xforwoocommerce.com" class="xforwc-button-primary x-color" target="_blank">XforWooCommerce.com</a></p>

						<br /><hr />

						<h3><span class="dashicons dashicons-admin-tools"></span> ' . esc_html__( 'Help Center', '^xwc' ) . '</h3>
						<p>' . esc_html__( 'Need support? Visit the Help Center.', '^xwc' ) . '</p>
						<p><a href="https://help.xforwoocommerce.com" class="xforwc-button-primary red" target="_blank">XforWooCommerce.com HELP</a></p>
						
						<br /><hr />

						<h3><span class="dashicons dashicons-update"></span> ' . esc_html__( 'Automatic Updates', '^xwc' ) . '</h3>
						<p>' . esc_html__( 'Get automatic updates, by downloading and installing the Envato Market plugin.', '^xwc' ) . '</p>
						<p><a href="https://envato.com/market-plugin/" class="svx-button" target="_blank">Envato Market Plugin</a></p>
						
						<br />',
					'section' => 'dashboard',
				),

				'wcmn_utility'            => array(
					'name'    => esc_html__( 'Plugin Options', '^xwc' ),
					'type'    => 'utility',
					'id'      => 'wcmn_utility',
					'desc'    => esc_html__( 'Quick export/import, backup and restore, or just reset your optons here', '^xwc' ),
					'section' => 'dashboard',
				),

				'wcmn_seo_separator'      => array(
					'name'     => esc_html__( 'Separator', '^xwc' ),
					'type'     => 'select',
					'id'       => 'wcmn_seo_separator',
					'desc'     => esc_html__( 'Select separator element for format builders', '^xwc' ),
					'options'  => array(
						'asd'      => 'asd',
						'-'        => '-',
						'&lt;'     => '&lt;',
						'&gt;'     => '&gt;',
						'&rarr;'   => '&rarr;',
						'&ndash;'  => '&ndash;',
						'&mdash;'  => '&mdash;',
						'&middot;' => '&middot;',
						'&sdo;'    => '&sdot;',
						'&bull;'   => '&bull;',
						'&hearts;' => '&hearts;',
						'&#x2605;' => '&#x2605;',
						'&#x2606;' => '&#x2606;',
					),
					'autoload' => false,
					'section'  => 'woocommerce',
					'default'  => '-',
				),

				'wcmn_seo_brand'          => array(
					'name'     => esc_html__( 'Brands', '^xwc' ),
					'type'     => 'select',
					'id'       => 'wcmn_seo_brand',
					'desc'     => esc_html__( 'Select brands taxonomy or attribute to use', '^xwc' ),
					'options'  => 'ajax:product_taxonomies:has_none',
					'autoload' => true,
					'section'  => 'woocommerce',
					'default'  => false,
				),

				'wcmn_seo_manufacturer'   => array(
					'name'     => esc_html__( 'Manufacturer', '^xwc' ),
					'type'     => 'select',
					'id'       => 'wcmn_seo_manufacturer',
					'desc'     => esc_html__( 'Select manufacturer taxonomy or attribute to use', '^xwc' ),
					'options'  => 'ajax:product_taxonomies:has_none',
					'autoload' => false,
					'section'  => 'woocommerce',
					'default'  => false,
				),

				'wcmn_seo_color'          => array(
					'name'     => esc_html__( 'Color', '^xwc' ),
					'type'     => 'select',
					'id'       => 'wcmn_seo_color',
					'desc'     => esc_html__( 'Select color taxonomy or attribute to use', '^xwc' ),
					'options'  => 'ajax:product_taxonomies:has_none',
					'autoload' => false,
					'section'  => 'woocommerce',
					'default'  => false,
				),

				'wcmn_seo_condition'      => array(
					'name'     => esc_html__( 'Condition', '^xwc' ),
					'type'     => 'select',
					'id'       => 'wcmn_seo_condition',
					'desc'     => esc_html__( 'Select condition taxonomy or attribute to use', '^xwc' ),
					'options'  => 'ajax:product_taxonomies:has_none',
					'autoload' => false,
					'section'  => 'woocommerce',
					'default'  => false,
				),

				'wcmn_seo_material'       => array(
					'name'     => esc_html__( 'Material', '^xwc' ),
					'type'     => 'select',
					'id'       => 'wcmn_seo_material',
					'desc'     => esc_html__( 'Select material taxonomy or attribute to use', '^xwc' ),
					'options'  => 'ajax:product_taxonomies:has_none',
					'autoload' => false,
					'section'  => 'woocommerce',
					'default'  => false,
				),

				'wcmn_seo_authors'        => array(
					'name'     => esc_html__( 'Use Authors (Vendors)', '^xwc' ),
					'type'     => 'checkbox',
					'id'       => 'wcmn_seo_authors',
					'desc'     => esc_html__( 'If this option is checked authors (vendors) will be used for author in the metadata. If this option is unchecked only site publisher will be used', '^xwc' ),
					'autoload' => false,
					'section'  => 'woocommerce',
					'default'  => 'no',
				),

				'wcmn_seo_product_image'  => array(
					'name'     => esc_html__( 'Product Image', '^xwc' ),
					'type'     => 'text',
					'id'       => 'wcmn_seo_product_image',
					'desc'     => esc_html__( 'If product has no featured image enter URL of the image to show', '^xwc' ),
					'autoload' => false,
					'section'  => 'woocommerce',
					'default'  => '',
				),

				'wcmn_seo_googleplus'     => array(
					'name'     => esc_html__( 'Google+ Profile ID', '^xwc' ),
					'type'     => 'text',
					'id'       => 'wcmn_seo_googleplus',
					'desc'     => esc_html__( 'Enter your Google+ Profile ID. If not set, admin user Google+ option will be used', '^xwc' ),
					'autoload' => true,
					'section'  => 'social',
					'default'  => '',
				),

				'wcmn_seo_facebook'       => array(
					'name'     => esc_html__( 'Facebook Profile ID', '^xwc' ),
					'type'     => 'text',
					'id'       => 'wcmn_seo_facebook',
					'desc'     => esc_html__( 'Enter your Facebook Profile ID. If not set, admin user Facebook option will be used', '^xwc' ),
					'autoload' => true,
					'section'  => 'social',
					'default'  => '',
				),

				'wcmn_seo_facebook_app'   => array(
					'name'     => esc_html__( 'Facebook APP ID', '^xwc' ),
					'type'     => 'text',
					'id'       => 'wcmn_seo_facebook_app',
					'desc'     => esc_html__( 'Enter your Facebook APP ID', '^xwc' ),
					'autoload' => true,
					'section'  => 'social',
					'default'  => '',
				),

				'wcmn_seo_twitter'        => array(
					'name'     => esc_html__( 'Twitter Username', '^xwc' ),
					'type'     => 'text',
					'id'       => 'wcmn_seo_twitter',
					'desc'     => esc_html__( 'Enter your Twitter username (without @). If not set, admin user Twitter option will be used', '^xwc' ),
					'autoload' => true,
					'section'  => 'social',
					'default'  => '',
				),

				'wcmn_seo_twitter_data'   => array(
					'name'     => esc_html__( 'Twitter Data', '^xwc' ),
					'type'     => 'multiselect',
					'id'       => 'wcmn_seo_twitter_data',
					'class'    => 'svx-selectize',
					'desc'     => esc_html__( 'Set which Twitter labels to include', '^xwc' ),
					'options'  => array(
						'price'        => esc_html__( 'Price', '^xwc' ),
						'availability' => esc_html__( 'Availability', '^xwc' ),
						'category'     => esc_html__( 'Category', '^xwc' ),
						'brand'        => esc_html__( 'Brand', '^xwc' ),
						'manufacturer' => esc_html__( 'Manufacturer', '^xwc' ),
						'color'        => esc_html__( 'Color', '^xwc' ),
						'condition'    => esc_html__( 'Condition', '^xwc' ),
						'material'     => esc_html__( 'Material', '^xwc' ),
					),
					'autoload' => false,
					'section'  => 'social',
					'default'  => array( 'price', 'category' ),
				),

				'wcmn_seo_products_title' => array(
					'name'     => esc_html__( 'Product Title', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_products_title',
					'desc'     => esc_html__( 'Enter products title format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'product',
					'default'  => '%title% %separator% %price% %separator% %brand% %separator% %site-title%',
					'class'    => 'seo-terms seo-type-product',
				),

				'wcmn_seo_products_desc'  => array(
					'name'     => esc_html__( 'Product Description', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_products_desc',
					'desc'     => esc_html__( 'Enter products description format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'product',
					'default'  => '%brand% %separator% %price% %separator% %product-short-desc%',
					'class'    => 'seo-terms seo-type-product',
				),

				'wcmn_seo_product_types'  => array(
					'name'     => esc_html__( 'Product Types', '^xwc' ),
					'type'     => 'list',
					'id'       => 'wcmn_seo_product_types',
					'desc'     => esc_html__( 'Use manager to create product types title and description formats', '^xwc' ),
					'autoload' => false,
					'section'  => 'product',
					'title'    => esc_html__( 'Type Name', '^xwc' ),
					'options'  => 'list',
					'settings' => array(

						'name'    => array(
							'name'    => esc_html__( 'Name', '^xwc' ),
							'type'    => 'text',
							'id'      => 'name',
							'desc'    => esc_html__( 'Enter name', '^xwc' ),
							'default' => '',
						),

						'type'    => array(
							'name'    => esc_html__( 'Select Type', '^xwc' ),
							'type'    => 'select',
							'id'      => 'type',
							'desc'    => esc_html__( 'Set search appearance format to the selected product type', '^xwc' ),
							'options' => 'ajax:product_types',
							'default' => '',
						),

						'disable' => array(
							'name'    => esc_html__( 'Disable Type', '^xwc' ),
							'type'    => 'checkbox',
							'id'      => 'disable',
							'desc'    => esc_html__( 'Check this option to remove this product type from search results', '^xwc' ),
							'default' => 'no',
						),

						'title'   => array(
							'name'    => esc_html__( 'Title', '^xwc' ),
							'type'    => 'textarea',
							'id'      => 'title',
							'desc'    => esc_html__( 'Enter product title format that will appear in search results', '^xwc' ),
							'default' => '',
							'class'   => 'seo-terms seo-type-product',
						),

						'desc'    => array(
							'name'    => esc_html__( 'Description', '^xwc' ),
							'type'    => 'textarea',
							'id'      => 'desc',
							'desc'    => esc_html__( 'Enter product description format that will appear in search results', '^xwc' ),
							'default' => '',
							'class'   => 'seo-terms seo-type-product',
						),

					),
				),

				'wcmn_seo_shop_title'     => array(
					'name'     => esc_html__( 'Shop/Archive Title', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_shop_title',
					'desc'     => esc_html__( 'Enter products title format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'shop',
					'default'  => '%title% %separator% %site-title%',
					'class'    => 'seo-terms seo-type-shop',
				),

				'wcmn_seo_shop_desc'      => array(
					'name'     => esc_html__( 'Shop/Archive Description', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_shop_desc',
					'desc'     => esc_html__( 'Enter products description format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'shop',
					'default'  => '%excerpt%',
					'class'    => 'seo-terms seo-type-shop',
				),

				'wcmn_seo_taxonomies'     => array(
					'name'     => esc_html__( 'Shop/Archive Types', '^xwc' ),
					'type'     => 'list',
					'id'       => 'wcmn_seo_taxonomies',
					'desc'     => esc_html__( 'Use manager to create Shop/Archive title and description formats', '^xwc' ),
					'autoload' => false,
					'section'  => 'shop',
					'title'    => esc_html__( 'Archive Name', '^xwc' ),
					'options'  => 'list',
					'settings' => array(

						'name'     => array(
							'name'    => esc_html__( 'Name', '^xwc' ),
							'type'    => 'text',
							'id'      => 'name',
							'desc'    => esc_html__( 'Enter name', '^xwc' ),
							'default' => '',
						),

						'taxonomy' => array(
							'name'    => esc_html__( 'Select Archive', '^xwc' ),
							'type'    => 'select',
							'id'      => 'taxonomy',
							'desc'    => esc_html__( 'Set search appearance format to the selected product archive type', '^xwc' ),
							'options' => 'ajax:product_taxonomies',
							'default' => '',
						),

						'disable'  => array(
							'name'    => esc_html__( 'Disable Archive', '^xwc' ),
							'type'    => 'checkbox',
							'id'      => 'disable',
							'desc'    => esc_html__( 'Check this option to remove this archive from search results', '^xwc' ),
							'default' => 'no',
						),

						'title'    => array(
							'name'    => esc_html__( 'Title', '^xwc' ),
							'type'    => 'textarea',
							'id'      => 'title',
							'desc'    => esc_html__( 'Enter product title format that will appear in search results', '^xwc' ),
							'default' => '',
							'class'   => 'seo-terms seo-type-product_taxonomy',
						),

						'desc'     => array(
							'name'    => esc_html__( 'Description', '^xwc' ),
							'type'    => 'textarea',
							'id'      => 'desc',
							'desc'    => esc_html__( 'Enter product description format that will appear in search results', '^xwc' ),
							'default' => '',
							'class'   => 'seo-terms seo-type-product_taxonomy',
						),

					),
				),

				'wcmn_seo_home_title'     => array(
					'name'     => esc_html__( 'Home Title', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_home_title',
					'desc'     => esc_html__( 'Enter home title format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'pages',
					'default'  => '%title% %separator% %site-title%',
					'class'    => 'seo-terms seo-type-page',
				),

				'wcmn_seo_home_desc'      => array(
					'name'     => esc_html__( 'Home Description', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_home_desc',
					'desc'     => esc_html__( 'Enter home description format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'pages',
					'default'  => '%excerpt%',
					'class'    => 'seo-terms seo-type-page',
				),

				'wcmn_seo_pages_title'    => array(
					'name'     => esc_html__( 'Pages Title', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_pages_title',
					'desc'     => esc_html__( 'Enter pages title format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'pages',
					'default'  => '%title% %separator% %site-title%',
					'class'    => 'seo-terms seo-type-page',
				),

				'wcmn_seo_pages_desc'     => array(
					'name'     => esc_html__( 'Pages Description', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_pages_desc',
					'desc'     => esc_html__( 'Enter pages description format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'pages',
					'default'  => '%excerpt%',
					'class'    => 'seo-terms seo-type-page',
				),

				'wcmn_seo_blog_title'     => array(
					'name'     => esc_html__( 'Blog Title', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_blog_title',
					'desc'     => esc_html__( 'Enter blog title format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'blog',
					'default'  => '%archive-title% %separator% %site-title%',
					'class'    => 'seo-terms seo-type-blog',
				),

				'wcmn_seo_blog_desc'      => array(
					'name'     => esc_html__( 'Blog Description', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_blog_desc',
					'desc'     => esc_html__( 'Enter blog description format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'blog',
					'default'  => '%archive-desc%',
					'class'    => 'seo-terms seo-type-blog',
				),

				'wcmn_seo_post_title'     => array(
					'name'     => esc_html__( 'Post Title', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_post_title',
					'desc'     => esc_html__( 'Enter post title format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'blog',
					'default'  => '%title% %separator% %site-title%',
					'class'    => 'seo-terms seo-type-post',
				),

				'wcmn_seo_post_desc'      => array(
					'name'     => esc_html__( 'Post Description', '^xwc' ),
					'type'     => 'textarea',
					'id'       => 'wcmn_seo_post_desc',
					'desc'     => esc_html__( 'Enter post description format that will appear in search results', '^xwc' ),
					'autoload' => false,
					'section'  => 'blog',
					'default'  => '%excerpt%',
					'class'    => 'seo-terms seo-type-post',
				),

				'wcmn_seo_add_meta'       => array(
					'name'     => esc_html__( 'Add Meta', '^xwc' ),
					'type'     => 'list',
					'id'       => 'wcmn_seo_add_meta',
					'desc'     => esc_html__( 'Use manager to create custom meta tags', '^xwc' ),
					'autoload' => false,
					'section'  => 'meta',
					'title'    => esc_html__( 'Meta Name', '^xwc' ),
					'options'  => 'list',
					'settings' => array(

						'name'      => array(
							'name'    => esc_html__( 'Name', '^xwc' ),
							'type'    => 'text',
							'id'      => 'name',
							'desc'    => esc_html__( 'Enter name', '^xwc' ),
							'default' => '',
						),

						'type'      => array(
							'name'    => esc_html__( 'Select Type', '^xwc' ),
							'type'    => 'select',
							'id'      => 'type',
							'desc'    => esc_html__( 'Select which META tag property you want to set', '^xwc' ),
							'options' => array(
								'name'     => 'name=""',
								'property' => 'property=""',
								'itemprop' => 'itemprop=""',
							),
							'default' => '',
						),

						'property'  => array(
							'name'    => esc_html__( 'Property Value', '^xwc' ),
							'type'    => 'textarea',
							'id'      => 'property',
							'desc'    => esc_html__( 'Enter property value', '^xwc' ),
							'default' => '',
						),

						'content'   => array(
							'name'    => esc_html__( 'Property Content', '^xwc' ),
							'type'    => 'textarea',
							'id'      => 'content',
							'desc'    => esc_html__( 'Enter property content', '^xwc' ),
							'default' => '',
							'class'   => 'seo-terms seo-type-all',
						),

						'condition' => array(
							'name'    => esc_html__( 'Conditional Functions', '^xwc' ),
							'type'    => 'text',
							'id'      => 'condition',
							'desc'    => esc_html__( 'Enter conditional functions for this meta e.g.', '^xwc' ) . ' is_woocommerce',
							'default' => '',
						),

					),
				),

			),
		);

		return SevenVX()->_do_options( $plugins, self::$plugin['label'] );
	}

}

XforWC_SEO_Settings::init();
