<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class XforWC_SpamControl_Settings {

	public static $plugin;

	public static function init() {

		self::$plugin = array(
			'name'    => 'Comment and Review Spam Control for WooCommerce',
			'xforwc'  => 'Spam Control',
			'slug'    => 'spam-control-xforwc',
			'label'   => 'spam_control_xforwc',
			'image'   => XforWC_SpamControl()->plugin_url() . '/includes/images/spam-control-for-woocommerce.png',
			'path'    => 'spam-control-xforwc/spam-control-xforwc',
			'version' => XforWC_SpamControl::$version,
		);

		if ( isset( $_GET['page'], $_GET['tab'] ) && 'wc-settings' === $_GET['page'] && 'spam_control_xforwc' === $_GET['tab'] ) {
			add_filter( 'svx_plugins_settings', array( 'XforWC_SpamControl_Settings', 'get_settings' ), 50 );
		}

		add_action( 'svx_ajax_saved_settings_spam_control_xforwc', array( 'XforWC_SpamControl_Function', 'start' ), 10, 1 );

		if ( function_exists( 'XforWC' ) ) {
			add_filter( 'xforwc_settings', array( 'XforWC_SpamControl_Settings', 'xforwc' ), 9999999181 );
			add_filter( 'xforwc_svx_get_spam_control_xforwc', array( 'XforWC_SpamControl_Settings', '_get_settings_xforwc' ) );
		}

		add_filter( 'svx_plugins', array( 'XforWC_SpamControl_Settings', 'add_plugin' ), 0 );

	}

	public static function xforwc( $settings ) {
		$settings['plugins'][] = self::$plugin;

		return $settings;
	}

	public static function add_plugin( $plugins ) {
		$plugins[ self::$plugin['label'] ] = array(
			'slug' => self::$plugin['label'],
			'name' => self::$plugin['xforwc'],
		);

		return $plugins;
	}

	public static function _get_settings_xforwc() {
		$settings = self::get_settings( array() );
		return $settings[ self::$plugin['label'] ];
	}

	public static function get_settings( $plugins ) {

		$plugins[ self::$plugin['label'] ] = array(
			'slug'     => self::$plugin['label'],
			'name'     => esc_html( function_exists( 'XforWC' ) ? self::$plugin['xforwc'] : self::$plugin['name'] ),
			'desc'     => esc_html( function_exists( 'XforWC' ) ? self::$plugin['name'] . ' v' . self::$plugin['version'] : esc_html__( 'Settings page for', '^xwc' ) . ' ' . self::$plugin['name'] ),
			'link'     => esc_url( 'https://xforwoocommerce.com/store/spam-control/' ),
			'ref'      => array(
				'name' => esc_html__( 'Visit XforWooCommerce.com', '^xwc' ),
				'url'  => 'https://xforwoocommerce.com',
			),
			'doc'      => array(
				'name' => esc_html__( 'Get help', '^xwc' ),
				'url'  => 'https://help.xforwoocommerce.com',
			),
			'sections' => array(
				'dashboard' => array(
					'name' => esc_html__( 'Dashboard', '^xwc' ),
					'desc' => esc_html__( 'Dashboard Overview', '^xwc' ),
				),
				'spam'      => array(
					'name' => esc_html__( 'Spam Control', '^xwc' ),
					'desc' => esc_html__( 'Spam Control Options', '^xwc' ),
				),
				'blacklist' => array(
					'name' => esc_html__( 'Blacklist', '^xwc' ),
					'desc' => esc_html__( 'Blacklist Options', '^xwc' ),
				),
			),
			'settings' => array(

				'wcmn_dashboard' => array(
					'type'    => 'html',
					'id'      => 'wcmn_dashboard',
					'desc'    => '	
                            <h3><span class="dashicons dashicons-store"></span> XforWooCommerce</h3>
                            <p>' . esc_html__( 'Visit XforWooCommerce.com store, demos and knowledge base.', '^xwc' ) . '</p>
                            <p><a href="https://xforwoocommerce.com" class="xforwc-button-primary x-color" target="_blank">XforWooCommerce.com</a></p>

                            <br /><hr />

                            <h3><span class="dashicons dashicons-admin-tools"></span> ' . esc_html__( 'Help Center', '^xwc' ) . '</h3>
                            <p>' . esc_html__( 'Need support? Visit the Help Center.', '^xwc' ) . '</p>
                            <p><a href="https://help.xforwoocommerce.com" class="xforwc-button-primary red" target="_blank">XforWooCommerce.com HELP</a></p>
                            
                            <br /><hr />

                            <h3><span class="dashicons dashicons-update"></span> ' . esc_html__( 'Automatic Updates', '^xwc' ) . '</h3>
                            <p>' . esc_html__( 'Get automatic updates, by downloading and installing the Envato Market plugin.', '^xwc' ) . '</p>
                            <p><a href="https://envato.com/market-plugin/" class="svx-button" target="_blank">Envato Market Plugin</a></p>
                            
                            <br />',
					'section' => 'dashboard',
				),

				'wcmn_utility'   => array(
					'name'    => esc_html__( 'Plugin Options', '^xwc' ),
					'type'    => 'utility',
					'id'      => 'wcmn_utility',
					'desc'    => esc_html__( 'Quick export/import, backup and restore, or just reset your optons here', '^xwc' ),
					'section' => 'dashboard',
				),

				'spam_control'   => array(
					'name'     => esc_html__( 'Activate Automatic Spam Control', '^xwc' ),
					'type'     => 'checkbox',
					'desc'     => esc_html__( 'Activate automatic spam control', '^xwc' ),
					'id'       => 'spam_control',
					'default'  => '',
					'autoload' => false,
					'section'  => 'spam',
					'class'    => 'svx-refresh-active-tab',
				),

				'spam_notice'    => array(
					'name'      => esc_html__( 'Notice', '^xwc' ),
					'type'      => 'html',
					'desc'      => '
						<div class="svx-option-header"><h3>' . esc_html__( 'Notice', '^xwc' ) . '</h3></div><div class="svx-option-wrapper"><div class="svx-notice svx-info"><strong>' . esc_html__( 'Automatic spam control is active.', '^xwc' ) . '</strong><br /><br />' . esc_html__( 'How this works? Read the following article', '^xwc' ) . ' &rarr; <a href="' . esc_url( 'https://help.xforwoocommerce.com/category/spam-control/' ) . '" target="_blank">' . esc_html__( 'Help Center', '^xwc' ) . '</a></div></div>',
					'section'   => 'spam',
					'id'        => 'spam_notice',
					'condition' => 'spam_control:yes',
				),

				'interval'       => array(
					'name'      => esc_html__( 'Spam Control Interval', '^xwc' ),
					'type'      => 'select',
					'desc'      => esc_html__( 'Set spam control interval', '^xwc' ),
					'section'   => 'spam',
					'id'        => 'interval',
					'default'   => 'twicedaily',
					'options'   => array(
						'hourly'     => esc_html__( 'Once Hourly', '^xwc' ),
						'twicedaily' => esc_html__( 'Twice Daily', '^xwc' ),
						'daily'      => esc_html__( 'Once Daily', '^xwc' ),
					),
					'autoload'  => false,
					'condition' => 'spam_control:yes',
				),

				'clear_spam'     => array(
					'name'      => esc_html__( 'Auto Clear Spam', '^xwc' ),
					'type'      => 'checkbox',
					'desc'      => esc_html__( 'Automatically clear spamed items', '^xwc' ),
					'id'        => 'clear_spam',
					'default'   => 'yes',
					'autoload'  => false,
					'section'   => 'spam',
					'condition' => 'spam_control:yes',
				),

				'clear_trash'    => array(
					'name'      => esc_html__( 'Auto Clear Trash', '^xwc' ),
					'type'      => 'checkbox',
					'desc'      => esc_html__( 'Automatically clear trashed items', '^xwc' ),
					'id'        => 'clear_trash',
					'default'   => 'yes',
					'autoload'  => false,
					'section'   => 'spam',
					'condition' => 'spam_control:yes',
				),

				'blacklist'      => array(
					'name'     => esc_html__( 'Manual Blacklist', '^xwc' ),
					'type'     => 'textarea',
					'desc'     => esc_html__( 'Manual blacklist supports usernames, IPs, IP ranges or words. Add one entry per line. Manual blacklists works in addition to automatic spam protection', '^xwc' ),
					'section'  => 'blacklist',
					'id'       => 'blacklist',
					'autoload' => false,
					'default'  => '',
				),

			),
		);

		return SevenVX()->_do_options( $plugins, self::$plugin['label'] );
	}

	public static function stripslashes_deep( $value ) {
		$value = is_array( $value ) ? array_map( 'stripslashes_deep', $value ) : stripslashes( $value );
		return $value;
	}

}

	XforWC_SpamControl_Settings::init();
